==> typegram-0.0.1-py3-none-any.whl: typegram/api/types/account/wallPapers.py <==

#===========================================================
#            Copyright (C) 2023-present AyiinXd
#===========================================================
#||                                                       ||
#||              _         _ _      __  __   _            ||
#||             /   _   _(_|_)_ __  / /__| |           ||
#||            / _ | | | | | | '_     _  | |           ||
#||           / ___  |_| | | | | | |/   (_| |           ||
#||          /_/   ___, |_|_|_| |_/_/___,_|           ||
#||                  |___/                                ||
#||                                                       ||
#===========================================================
# Appreciating the work of others is not detrimental to you
#===========================================================
#

from io import BytesIO
from typing import Any, Union, List, Optional

from typegram.api import ayiin, functions
from typegram.api.object import Object
from typegram.api.utils import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector



class WallPapers(Object):  # type: ignore
    """Telegram API type.

    Constructor of :obj:`~typegram.api.ayiin.account.WallPapers`.

    Details:
        - Layer: ``181``
        - ID: ``CDC3858C``

hash (``int`` ``64-bit``):
                    N/A
                
        wallpapers (List of :obj:`WallPaper<typegram.api.ayiin.WallPaper>`):
                    N/A
                
    Functions:
        This object can be returned by 18 functions.

        .. currentmodule:: typegram.api.functions

        .. autosummary::
            :nosignatures:

            account.WallPapers
            account.PrivacyRules
            account.PasswordSettings
            account.TmpPassword
            account.AuthorizationForm
            account.SentEmailCode
            account.EmailVerified
            account.Takeout
            account.Themes
            account.SavedRingtones
            account.SavedRingtone
            account.EmojiStatuses
            account.ResolvedBusinessChatLinks
    """

    __slots__: List[str] = ["hash", "wallpapers"]

    ID = 0xcdc3858c
    QUALNAME = "functions.typesaccount.WallPapers"

    def __init__(self, *, hash: int, wallpapers: List["ayiin.WallPaper"]) -> None:
        
                self.hash = hash  # long
        
                self.wallpapers = wallpapers  # WallPaper

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "WallPapers":
        # No flags
        
        hash = Long.read(b)
        
        wallpapers = Object.read(b)
        
        return WallPapers(hash=hash, wallpapers=wallpapers)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Long(self.hash))
        
        b.write(Vector(self.wallpapers))
        
        return b.getvalue()

==> typegram-0.0.2-py3-none-any.whl: typegram/api/types/account/wallPapers.py <==

#===========================================================
#            Copyright (C) 2023-present AyiinXd
#===========================================================
#||                                                       ||
#||              _         _ _      __  __   _            ||
#||             /   _   _(_|_)_ __  / /__| |           ||
#||            / _ | | | | | | '_     _  | |           ||
#||           / ___  |_| | | | | | |/   (_| |           ||
#||          /_/   ___, |_|_|_| |_/_/___,_|           ||
#||                  |___/                                ||
#||                                                       ||
#===========================================================
# Appreciating the work of others is not detrimental to you
#===========================================================
#

from io import BytesIO
from typing import Any, Union, List, Optional

from typegram import api
from typegram.api.object import Object
from typegram.api.utils import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector



class WallPapers(Object):  # type: ignore
    """Telegram API type.

    Constructor of :obj:`~typegram.api.ayiin.account.WallPapers`.

    Details:
        - Layer: ``181``
        - ID: ``CDC3858C``

hash (``int`` ``64-bit``):
                    N/A
                
        wallpapers (List of :obj:`WallPaper<typegram.api.ayiin.WallPaper>`):
                    N/A
                
    Functions:
        This object can be returned by 18 functions.

        .. currentmodule:: typegram.api.functions

        .. autosummary::
            :nosignatures:

            account.getWallPapers
    """

    __slots__: List[str] = ["hash", "wallpapers"]

    ID = 0xcdc3858c
    QUALNAME = "types.account.wallPapers"

    def __init__(self, *, hash: int, wallpapers: List["api.ayiin.WallPaper"]) -> None:
        
                self.hash = hash  # long
        
                self.wallpapers = wallpapers  # WallPaper

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "WallPapers":
        # No flags
        
        hash = Long.read(b)
        
        wallpapers = Object.read(b)
        
        return WallPapers(hash=hash, wallpapers=wallpapers)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Long(self.hash))
        
        b.write(Vector(self.wallpapers))
        
        return b.getvalue()
